local max = math.max
local rnd = love.math.random
local warning = ""

local function checkJoystickConnected(self)
	if (self.joystick ~= nil) and (not self.joystick:isConnected()) then
		self.joystick = nil
	end
end

local function checkJoystickInput(self)
	local linearX,linearY = 0,0
	if self.joystick ~= nil then
		local numAxes = self.joystick:getAxisCount( )
		local axis = {}
		if numAxes >= 2 then
			axis = {self.joystick:getAxes( )}
	
			--Right
			if axis[numAxes-1] == 1 then 
				linearX = self.velocity
				self.facing = "right"
			end
	
			--Left
			if axis[numAxes-1] == -1 then 
				linearX = -self.velocity
				self.facing = "left"
			end
	
			--Down		
			if axis[numAxes] == 1 then 
				linearY = self.velocity
			end
	
			--Up	
			if axis[numAxes] == -1 then 
				linearY = -self.velocity
			end
		warning = ""
		else
			warning = "Your joystick is not supported!"
		end
	end
	return linearX,linearY
end

local Player = {}
Player.__index = Player

function newPlayer(name, power, x, y, velocity, range, cooldown, sprites, joystick)
	local p  = {}
	p.name = name
	p.joystick = joystick
	p.power = power
	p.velocity = velocity
	p.range = range
	p.cooldown = cooldown
	p.timecount = 0
	p.sprites = sprites
	p.facing = "right"
	--p.animation1 = newAnimation(sprites[1], 512, 342, 0.15, 5)
	--p.animation2 = newAnimation(sprites[2], 512, 342, 0.15, 5)	
	p.body = love.physics.newBody(world, x, y, "dynamic")
	p.shape = love.physics.newCircleShape(25)
	p.fixture = love.physics.newFixture(p.body, p.shape, 1)
	p.life = 3
	p.isAlive = true
	p.color = {rnd(255),rnd(255),rnd(255)}
	
	return setmetatable(p, Player)
end

function Player:update(dt)
	checkJoystickConnected(self)
	if self.isAlive == true then
		--self.animation1:update(dt) 
		--self.animation2:update(dt)
		--self.power.update(dt)
		self.timecount = max ( 0, self.timecount - dt )
		if self.life == 0 then
			playerDie(self)
		else
			self.body:setLinearVelocity(checkJoystickInput(self))
		end
	end
end

function Player:draw()
	local zoom = .4
	if self.isAlive == true then
		love.graphics.setColor(255, 255, 255)
		--[[if (self.facing == "left") then
			self.animation1:draw(self.body:getX()-self.sprites[1]:getWidth()*zoom, self.body:getY()-self.sprites[1]:getHeight()*zoom,0,zoom,zoom)
		else
			self.animation12:draw(self.body:getX()-self.sprites[2]:getWidth()*zoom, self.body:getY()-self.sprites[2]:getHeight()*zoom,0,zoom,zoom)
		end]]
				
		love.graphics.setColor(self.color) --set the drawing color to red for the player
		love.graphics.circle("line", self.body:getX(),self.body:getY(), self.shape:getRadius())
		--self.power.draw(self.facing)
		
		--love.graphics.printf(" X: "..self.body:getX(), self.body:getX()-150, self.body:getY()-120, 400, "center")
		--love.graphics.printf(" Y: "..self.body:getY(), self.body:getX()-150, self.body:getY()-100, 400, "center")
		if self.joystick~= nil and self.joystick:isConnected() then
			love.graphics.printf(warning,self.body:getX()-90, self.body:getY()-60,300, "left")
		end
	end
end

function playerDie(player)
	--love.audio.play(fail)
	if player.isAlive == true then
		love.timer.sleep( 1 )
		player.body:destroy()	
		player.isAlive = false
	end				
end

function Player:attack()
	if self.isAlive == true then
		if self.timecount ==0 then
			--love.audio.play(sonarsom)
			--self.power.fire(self.facing)
			self.timecount = self.cooldown
		end
	end
end



